@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ada-ts-mode" "0.8.3"
+(define-package "ada-ts-mode" "20251125.2018"
   "Major mode for Ada using Tree-sitter."
   '((emacs "29.1"))
   :url "https://github.com/brownts/ada-ts-mode"
